@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 from botocore.paginate import Paginator as Boto3Paginator
 from botocore.waiter import Waiter as Boto3Waiter
@@ -91,6 +92,7 @@ class ElasticLoadBalancingClient:
     [ElasticLoadBalancing.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/elb.html#ElasticLoadBalancing.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def add_tags(self, LoadBalancerNames: List[str], Tags: List["TagTypeDef"]) -> Dict[str, Any]:
